import { Stack } from '@mantine/core';
import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import tippy from 'tippy.js';
// const clamp = (value: number, left: number, right: number) =>
//   Math.min(Math.max(value, left), right)
class TipContainer extends Component {
    constructor() {
        super(...arguments);
        this.state = {
            height: 0,
            width: 0,
            html: ''
        };
        this.node = null;
        this.tippy = null;
        this.updatePosition = () => {
            if (!this.node) {
                return;
            }
            const { offsetHeight, offsetWidth } = this.node;
            this.setState({
                height: offsetHeight,
                width: offsetWidth
            });
        };
    }
    componentDidUpdate(nextProps) {
        console.log(nextProps);
        if (this.props.children !== nextProps.children) {
            this.updatePosition();
        }
    }
    componentDidMount() {
        if (!this.renderedElement) {
            const renderedElement = document.createElement('div');
            this.renderedElement = renderedElement;
        }
        if (!this.target) {
            const target = document.createElement('div');
            document.querySelector('.PdfHighlighter').appendChild(target);
            this.target = target;
        }
        ReactDOM.render(React.createElement(React.Fragment, null, this.props.children), this.renderedElement);
        this.forceUpdate();
        setTimeout(this.updatePosition, 0);
        // document.querySelector('.PdfHighlighter').addEventListener('scroll', () => {
        //   this.tippy[0].destroy()
        // })
    }
    componentWillUnmount() {
        // this.renderedElement?.remove()
        // this.target?.remove()
        // this.tippy?.destroy()
    }
    render() {
        if (!this.renderedElement) {
            return null;
        }
        const { children, style } = this.props;
        const { height, width } = this.state;
        const isStyleCalculationInProgress = width === 0 && height === 0;
        const left = style.left - width / 2;
        if (children) {
            const target = this.target;
            target.style.top = style.top + 'px';
            target.style.position = 'absolute';
            target.style.left = style.left + 'px';
            // @ts-ignore
            this.tippy = tippy(target, {
                theme: 'light',
                getReferenceClientRect: () => target.getBoundingClientRect(),
                appendTo: () => document.querySelector('.PdfHighlighter'),
                content: this.renderedElement.innerHTML,
                showOnCreate: true,
                allowHTML: true,
                interactive: true,
                trigger: 'manual',
                placement: 'bottom',
                onClickOutside: () => {
                    var _a;
                    (_a = this.tippy) === null || _a === void 0 ? void 0 : _a.hide();
                    setTimeout(() => {
                        var _a, _b, _c;
                        (_a = this.renderedElement) === null || _a === void 0 ? void 0 : _a.remove();
                        (_b = this.target) === null || _b === void 0 ? void 0 : _b.remove();
                        (_c = this.tippy) === null || _c === void 0 ? void 0 : _c.destroy();
                    }, 500);
                }
            });
        }
        else {
            return (React.createElement("div", { className: "PdfHighlighter__tip-container", style: {
                    visibility: isStyleCalculationInProgress ? 'hidden' : 'visible',
                    top: style.top,
                    left
                }, ref: (node) => {
                    this.node = node;
                } },
                React.createElement(React.Fragment, null,
                    React.createElement(Stack, { sx: { opacity: '0', filter: 'alpha(opacity=0)' } },
                        React.createElement("textarea", { autoFocus: true, ref: (node) => {
                                setTimeout(() => {
                                    node === null || node === void 0 ? void 0 : node.focus();
                                }, 50);
                            } })))));
        }
        return React.createElement(React.Fragment, null);
    }
}
export default TipContainer;
//# sourceMappingURL=TipContainer.js.map